import argparse
import os
from pathlib import Path
import subprocess
import sys
import time

from .config import VERSION


def get_beet_yaml(namespace: str):
    return f"""output: build
require: [jmcbeet]

data_pack:
  load: [src]
  name: datapack

pipeline: [mecha]

meta:
  mecha:
    formatting: minify
  jmc:
    namespace: {namespace}
    file: src/data/{namespace}/main.jmc
"""


def main():
    cwd = Path(os.getcwd())
    parser = argparse.ArgumentParser(
        description="JMC-Beet integration")
    parser.add_argument("--version", "-v", action='version', version=VERSION)
    subparser = parser.add_subparsers(dest="command", required=True)
    init_parser = subparser.add_parser(
        "init", help="initialize beet workspace for jmc")
    init_parser.add_argument(
        "--namespace",
        "-n",
        required=False,
        type=str)

    args = parser.parse_args()
    if args.command == "init":
        namespace = args.namespace
        if namespace is None:
            namespace = input("namespace: ")

    if not (cwd / "beet.yaml").is_file():
        with (cwd / "beet.yaml").open("w+") as file:
            file.write(get_beet_yaml(namespace))

    namespace_folder = cwd / "src" / "data" / namespace
    namespace_folder.mkdir(parents=True, exist_ok=True)
    (namespace_folder / "main.jmc").touch()
    (namespace_folder / "main.hjmc").touch()

    retcode = subprocess.call(
        [sys.executable, "-m", "pip", "install", "mecha"])
    time.sleep(0.5)
    subprocess.call(["beet"])
    is_in_venv = sys.prefix != sys.base_prefix
    if retcode != 0:
        print("\n[JMC-Beet] Unable to install `mecha`, administrator privileges required. Run `pip install mecha` manually.")
    if not is_in_venv:
        print("[JMC-Beet] Virtual environment not detected.")



"""Setup file for pypi"""
from pathlib import Path
from setuptools import setup, find_packages
from jmcbeet import VERSION

DESCRIPTION = "A Beet plugin that act as an adapter for JMC"
version = VERSION.replace("-alpha.", "a").replace("-beta.", "b")[1:]
setup(
    name="jmc-beet",
    version=version,
    author="WingedSeal",
    author_email="firm09719@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description="""
# jmc-beet
A plugin for integrating JMC into Beet
""",
    packages=find_packages(),
    install_requires=[
        "jmcfunction",
        "beet"
    ],
    keywords=[
        "python",
        "minecraft",
        "mcfunction",
        "datapack",
        "compiler",
        "beet"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires=">=3.10",
    entry_points={
        "console_scripts": [
            "jmcbeet=jmcbeet.__main__:main",
        ]
    },
    project_urls={
        "Documentation": "https://jmc.wingedseal.com/",
        "Repository": "https://github.com/WingedSeal/jmc-beet",
    },
    license="MIT License"
)
